==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/BackupVaultArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Backup Vault
 * @property featureSettings Feature Settings
 * @property monitoringSettings Monitoring Settings
 * @property securitySettings Security Settings
 * @property storageSettings Storage Settings
 */
public data class BackupVaultArgs(
    public val featureSettings: Output<FeatureSettingsArgs>? = null,
    public val monitoringSettings: Output<MonitoringSettingsArgs>? = null,
    public val securitySettings: Output<SecuritySettingsArgs>? = null,
    public val storageSettings: Output<List<StorageSettingArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs =
        com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs.builder()
            .featureSettings(featureSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitoringSettings(
                monitoringSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .securitySettings(securitySettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageSettings(
                storageSettings.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [BackupVaultArgs].
 */
@PulumiTagMarker
public class BackupVaultArgsBuilder internal constructor() {
    private var featureSettings: Output<FeatureSettingsArgs>? = null

    private var monitoringSettings: Output<MonitoringSettingsArgs>? = null

    private var securitySettings: Output<SecuritySettingsArgs>? = null

    private var storageSettings: Output<List<StorageSettingArgs>>? = null

    /**
     * @param value Feature Settings
     */
    @JvmName("kngruwymsulbwplj")
    public suspend fun featureSettings(`value`: Output<FeatureSettingsArgs>) {
        this.featureSettings = value
    }

    /**
     * @param value Monitoring Settings
     */
    @JvmName("cmcrrhgkecixvusm")
    public suspend fun monitoringSettings(`value`: Output<MonitoringSettingsArgs>) {
        this.monitoringSettings = value
    }

    /**
     * @param value Security Settings
     */
    @JvmName("ocjsuwanfsfmlkbl")
    public suspend fun securitySettings(`value`: Output<SecuritySettingsArgs>) {
        this.securitySettings = value
    }

    /**
     * @param value Storage Settings
     */
    @JvmName("nfyvtidyjcvmvles")
    public suspend fun storageSettings(`value`: Output<List<StorageSettingArgs>>) {
        this.storageSettings = value
    }

    @JvmName("urmvftjtslkbhilq")
    public suspend fun storageSettings(vararg values: Output<StorageSettingArgs>) {
        this.storageSettings = Output.all(values.asList())
    }

    /**
     * @param values Storage Settings
     */
    @JvmName("rvappxsxwohpawlp")
    public suspend fun storageSettings(values: List<Output<StorageSettingArgs>>) {
        this.storageSettings = Output.all(values)
    }

    /**
     * @param value Feature Settings
     */
    @JvmName("gyhiygwdleepnisn")
    public suspend fun featureSettings(`value`: FeatureSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.featureSettings = mapped
    }

    /**
     * @param argument Feature Settings
     */
    @JvmName("dvvflhkuqxxijuch")
    public suspend fun featureSettings(argument: suspend FeatureSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = FeatureSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.featureSettings = mapped
    }

    /**
     * @param value Monitoring Settings
     */
    @JvmName("hopvjujnoftvguuf")
    public suspend fun monitoringSettings(`value`: MonitoringSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitoringSettings = mapped
    }

    /**
     * @param argument Monitoring Settings
     */
    @JvmName("hqemgjhejpkcirqn")
    public suspend
    fun monitoringSettings(argument: suspend MonitoringSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = MonitoringSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitoringSettings = mapped
    }

    /**
     * @param value Security Settings
     */
    @JvmName("egccljgiliwpxehe")
    public suspend fun securitySettings(`value`: SecuritySettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.securitySettings = mapped
    }

    /**
     * @param argument Security Settings
     */
    @JvmName("wyxbbljxeytsgkij")
    public suspend fun securitySettings(argument: suspend SecuritySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SecuritySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.securitySettings = mapped
    }

    /**
     * @param value Storage Settings
     */
    @JvmName("msposcmbdpjrjtqf")
    public suspend fun storageSettings(`value`: List<StorageSettingArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage Settings
     */
    @JvmName("gumllmvsidqvsbpp")
    public suspend fun storageSettings(argument: List<suspend StorageSettingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StorageSettingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage Settings
     */
    @JvmName("cnecfiliwtlxjpkg")
    public suspend fun storageSettings(
        vararg
        argument: suspend StorageSettingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StorageSettingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage Settings
     */
    @JvmName("wnnfaavsmhvrxkxm")
    public suspend fun storageSettings(argument: suspend StorageSettingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(StorageSettingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    /**
     * @param values Storage Settings
     */
    @JvmName("uutmcgrgeeivbbib")
    public suspend fun storageSettings(vararg values: StorageSettingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageSettings = mapped
    }

    internal fun build(): BackupVaultArgs = BackupVaultArgs(
        featureSettings = featureSettings,
        monitoringSettings = monitoringSettings,
        securitySettings = securitySettings,
        storageSettings = storageSettings ?: throw PulumiNullFieldException("storageSettings"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/BackupVaultArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Backup Vault
 * @property featureSettings Feature Settings
 * @property monitoringSettings Monitoring Settings
 * @property securitySettings Security Settings
 * @property storageSettings Storage Settings
 */
public data class BackupVaultArgs(
    public val featureSettings: Output<FeatureSettingsArgs>? = null,
    public val monitoringSettings: Output<MonitoringSettingsArgs>? = null,
    public val securitySettings: Output<SecuritySettingsArgs>? = null,
    public val storageSettings: Output<List<StorageSettingArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs =
        com.pulumi.azurenative.dataprotection.inputs.BackupVaultArgs.builder()
            .featureSettings(featureSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitoringSettings(
                monitoringSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .securitySettings(securitySettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageSettings(
                storageSettings.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [BackupVaultArgs].
 */
@PulumiTagMarker
public class BackupVaultArgsBuilder internal constructor() {
    private var featureSettings: Output<FeatureSettingsArgs>? = null

    private var monitoringSettings: Output<MonitoringSettingsArgs>? = null

    private var securitySettings: Output<SecuritySettingsArgs>? = null

    private var storageSettings: Output<List<StorageSettingArgs>>? = null

    /**
     * @param value Feature Settings
     */
    @JvmName("ssemhwomljupbkxp")
    public suspend fun featureSettings(`value`: Output<FeatureSettingsArgs>) {
        this.featureSettings = value
    }

    /**
     * @param value Monitoring Settings
     */
    @JvmName("jbvjqnugxaaehsej")
    public suspend fun monitoringSettings(`value`: Output<MonitoringSettingsArgs>) {
        this.monitoringSettings = value
    }

    /**
     * @param value Security Settings
     */
    @JvmName("fqlunnwawsayvmuh")
    public suspend fun securitySettings(`value`: Output<SecuritySettingsArgs>) {
        this.securitySettings = value
    }

    /**
     * @param value Storage Settings
     */
    @JvmName("bschemqnexcsyvth")
    public suspend fun storageSettings(`value`: Output<List<StorageSettingArgs>>) {
        this.storageSettings = value
    }

    @JvmName("rhldheynaegqbfxc")
    public suspend fun storageSettings(vararg values: Output<StorageSettingArgs>) {
        this.storageSettings = Output.all(values.asList())
    }

    /**
     * @param values Storage Settings
     */
    @JvmName("stbseltkxdqqwaai")
    public suspend fun storageSettings(values: List<Output<StorageSettingArgs>>) {
        this.storageSettings = Output.all(values)
    }

    /**
     * @param value Feature Settings
     */
    @JvmName("biequrslvggsocpr")
    public suspend fun featureSettings(`value`: FeatureSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.featureSettings = mapped
    }

    /**
     * @param argument Feature Settings
     */
    @JvmName("kccfrosqjovojbca")
    public suspend fun featureSettings(argument: suspend FeatureSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = FeatureSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.featureSettings = mapped
    }

    /**
     * @param value Monitoring Settings
     */
    @JvmName("fekhfxjjontynmcj")
    public suspend fun monitoringSettings(`value`: MonitoringSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitoringSettings = mapped
    }

    /**
     * @param argument Monitoring Settings
     */
    @JvmName("yomowcxwfuuujnpd")
    public suspend
    fun monitoringSettings(argument: suspend MonitoringSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = MonitoringSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitoringSettings = mapped
    }

    /**
     * @param value Security Settings
     */
    @JvmName("jpraxmjatiedhabf")
    public suspend fun securitySettings(`value`: SecuritySettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.securitySettings = mapped
    }

    /**
     * @param argument Security Settings
     */
    @JvmName("uisbsggxthjgsxol")
    public suspend fun securitySettings(argument: suspend SecuritySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SecuritySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.securitySettings = mapped
    }

    /**
     * @param value Storage Settings
     */
    @JvmName("scrgmeovhniapkbv")
    public suspend fun storageSettings(`value`: List<StorageSettingArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage Settings
     */
    @JvmName("yckrygpumrwlffpk")
    public suspend fun storageSettings(argument: List<suspend StorageSettingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StorageSettingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage Settings
     */
    @JvmName("niilovfxrmkxirfp")
    public suspend fun storageSettings(
        vararg
        argument: suspend StorageSettingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StorageSettingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    /**
     * @param argument Storage Settings
     */
    @JvmName("mqtdatpgofehgjol")
    public suspend fun storageSettings(argument: suspend StorageSettingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(StorageSettingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.storageSettings = mapped
    }

    /**
     * @param values Storage Settings
     */
    @JvmName("cdyybeeviwefxdov")
    public suspend fun storageSettings(vararg values: StorageSettingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageSettings = mapped
    }

    internal fun build(): BackupVaultArgs = BackupVaultArgs(
        featureSettings = featureSettings,
        monitoringSettings = monitoringSettings,
        securitySettings = securitySettings,
        storageSettings = storageSettings ?: throw PulumiNullFieldException("storageSettings"),
    )
}
